@@ -1,10 +1,23 @@
 # -*- coding: utf-8 -*-
 
+from core_mixins import StrEnum
+
 try:
-    from enum import StrEnum
+    from http import HTTPStatus as _HTTPStatus
 
 except ImportError:
-    from core_mixins.compatibility import StrEnum
+    from .utils import HTTPStatus as _HTTPStatus  # type: ignore
+
+
+__all__ = [
+    "HTTPStatus",
+    "StatusInfo"
+]
+
+
+# Type alias that works with both standard library
+# and the custom HTTPStatus...
+HTTPStatus = _HTTPStatus
 
 
 class StatusInfo(StrEnum):
